@@ -239,11 +239,20 @@ static GtkWidget *cache_overview(cache_context_t *context) {
 
 /* slow but short, we don't need performance here ... */
 static void rot13(char *t) {
+  int braces = 0;
+
   while(*t) {
-    if(((*t >= 'a') && (*t < 'n')) ||
-       ((*t >= 'A') && (*t < 'N'))) *t += 13;
-    else if(((*t >= 'n') && (*t <= 'z')) ||
-	    ((*t >= 'N') && (*t <= 'Z'))) *t -= 13;
+    if(!braces) {
+      if(*t == '[') 
+	braces++;
+      else if(((*t >= 'a') && (*t < 'n')) ||
+	      ((*t >= 'A') && (*t < 'N'))) *t += 13;
+      else if(((*t >= 'n') && (*t <= 'z')) ||
+	      ((*t >= 'N') && (*t <= 'Z'))) *t -= 13;
+    } else {
+      if(braces > 0 && *t == ']')
+	braces--;
+    }
 
     t++;
   }
