@@ -84,7 +84,11 @@ static store_t store[] = {
   { "goto_dss",         STORE_BOOL,   OFFSET(goto_disable_screensaver) },
   { "cachelist_update", STORE_BOOL,   OFFSET(cachelist_update) },
 #endif
-
+#ifdef ENABLE_OSM_GPS_MAP
+  { "map_lat",          STORE_FLOAT,  OFFSET(map.pos.lat) },
+  { "map_lon",          STORE_FLOAT,  OFFSET(map.pos.lon) },
+  { "map_zoom",         STORE_INT,    OFFSET(map.zoom) },
+#endif
   { NULL, -1, -1 }
 };
 
