@@ -18,6 +18,7 @@
  */
 
 #include "gpxview.h"
+#include <math.h>     // for isnan()
 
 struct icon_data {
   GdkPixbuf **data;
@@ -30,7 +31,7 @@ struct icon_data {
   { NULL, 9 },                 /* ICON_HEADING    */
   { NULL, WPT_SYM_MAX+1 },     /* ICON_WPT        */
   { NULL, 1 },                 /* ICON_TB         */
-  { NULL, 9 },                 /* ICON_MISC       */
+  { NULL, 13 },                /* ICON_MISC       */
   { NULL, 3 },                 /* ICON_FILE       */
   { NULL, -1 }
 };
@@ -81,7 +82,8 @@ const char *tb_icon_name[] = {
 /* ICON_MISC         */
 const char *misc_icon_name[] = {
   "maemo-mapper-out", "override", "locked", "unlocked", "found", 
-  "maemo-mapper-in", "note", "delete", "paypal"
+  "maemo-mapper-in", "note", "delete", "paypal", 
+  "user", "zoomin", "zoomout", "info"
 };
 
 /* ICON_FILE         */
