@@ -1077,7 +1077,7 @@ cb_menu_about(GtkWidget *window, gpointer data) {
   
   GtkWidget *hbox = gtk_hbox_new(FALSE, 8);
   gtk_box_pack_start(GTK_BOX(hbox),
-		     gtk_label_new(_("Do you you ĺike GPXView?")), 
+		     gtk_label_new(_("Do you like GPXView?")), 
 		     FALSE, FALSE, 0);
 
   GtkWidget *button = gtk_button_new();
