@@ -20,6 +20,19 @@
 #ifndef MAP_TOOL_H
 #define MAP_TOOL_H
 
+typedef struct map_context_s {
+  appdata_t *appdata;
+  GtkWidget *window;
+  GtkWidget *widget;
+  GtkWidget *zoomin, *zoomout, *gps;
+  gint handler_id;
+  cache_t *press_on;
+#if MAEMO_VERSION_MAJOR == 5
+  GtkWidget *old_view;
+#endif
+} map_context_t;
+
+
 extern void map(appdata_t *appdata);
 
 #endif // MAP_TOOL_H
